@@ -4,14 +4,14 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.1.0';
+our $VERSION = 'v2.2.0';
 
 use Perl6::Export::Attrs;
 use Narada;
 use Path::Tiny 0.053;
 
-use constant IS_NARADA1 => eval { local $SIG{__DIE__}; Narada::detect('narada-1') } || undef;
-use constant CONFIG_DIR => IS_NARADA1 ? 'db' : 'mysql';
+use constant NARADA     => eval { local $SIG{__DIE__}; Narada::detect() } || q{};
+use constant DB_DIR     => NARADA eq 'narada-1' ? 'db' : 'mysql';
 use constant MAXPERM    => 0666; ## no critic (ProhibitLeadingZeros)
 
 my $VAR_NAME = qr{\A(?:(?![.][.]?/)[\w.-]+/)*[\w.-]+\z}xms;
@@ -21,11 +21,13 @@ sub get_config :Export {
     my ($var) = @_;
     croak 'Usage: get_config(NAME)' if @_ != 1;
     $var =~ /$VAR_NAME/xms              or croak "Bad config: $var";
+    return undef if !NARADA;    ## no critic (ProhibitExplicitReturnUndef)
     return path("config/$var")->slurp_utf8;
 }
 
 sub get_config_line :Export {
     my ($val) = get_config(@_);
+    return $val if !defined $val;
     $val =~ s/\n\s*\z//xms;
     croak 'Config contain more than one line' if $val =~ /\n/xms;
     return $val;
@@ -33,14 +35,14 @@ sub get_config_line :Export {
 
 sub get_db_config :Export {
     my %db;
-    $db{db} = eval { get_config_line(CONFIG_DIR.'/db') };
+    $db{db} = eval { get_config_line(DB_DIR.'/db') };
     if (!defined $db{db} || !length $db{db}) {
         return;
     }
-    $db{login}= get_config_line(CONFIG_DIR.'/login');
-    $db{pass} = get_config_line(CONFIG_DIR.'/pass');
-    $db{host} = eval { get_config_line(CONFIG_DIR.'/host') } || q{};
-    $db{port} = eval { get_config_line(CONFIG_DIR.'/port') } || q{};
+    $db{login}= get_config_line(DB_DIR.'/login');
+    $db{pass} = get_config_line(DB_DIR.'/pass');
+    $db{host} = eval { get_config_line(DB_DIR.'/host') } || q{};
+    $db{port} = eval { get_config_line(DB_DIR.'/port') } || q{};
     $db{dsn_nodb}  = 'dbi:mysql:';
     $db{dsn_nodb} .= ';host='.$db{host} if $db{host}; ## no critic (ProhibitPostfixControls)
     $db{dsn_nodb} .= ';port='.$db{port} if $db{port}; ## no critic (ProhibitPostfixControls)
@@ -52,6 +54,7 @@ sub set_config :Export {
     my ($var, $val) = @_;
     croak 'Usage: set_config(NAME, VALUE)' if @_ != 2;
     $var =~ /$VAR_NAME/xms              or croak "Bad config: $var";
+    croak 'Narada::Config was loaded not in narada directory' if !NARADA;
     my $cfg = path("config/$var");
     $cfg->parent->mkpath;
     $cfg->spew_utf8($val);
@@ -72,7 +75,7 @@ Narada::Config - manage project configuration
 
 =head1 VERSION
 
-This document describes Narada::Config version v2.1.0
+This document describes Narada::Config version v2.2.0
 
 
 =head1 SYNOPSIS
